WireType

Enum WireType 

#[repr(u8)]
pub enum WireType { Fixed1Byte = 0, Fixed2Byte = 1, Fixed4Byte = 2, Fixed8Byte = 3, Fixed16Byte = 4, VarInt = 5, LengthPrefixed = 6, List = 7, }
A wire type.

The discriminants are the on-wire encoding of the wire type — they appear in the high or low 3 bits of header bytes throughout the format. Do not reorder or change them without breaking wire compatibility.

Variants



Fixed1Byte = 0

A fixed 1-byte of data.



Fixed2Byte = 1

A fixed 2-bytes of data.



Fixed4Byte = 2

A fixed 4-bytes of data.



Fixed8Byte = 3

A fixed 8-bytes of data.



Fixed16Byte = 4

A fixed 16-bytes of data.



VarInt = 5

A variable-length encoded integer.



LengthPrefixed = 6

A variable-length encoded integer n followed by n bytes.



List = 7

A wire-type w dual-encoded with a var-primitive n, followed by n bytes. The n bytes are x sequential instances of w where x is unknown (until the list is decoded).

Implementations

Source

impl WireType

Bits

pub fn from_low_3_bits(b: u8) -> Self

Gets the wire type from the low 3-bits of b.

pub fn from_high_3_bits(b: u8) -> Self

Gets the wire type from the high 3-bits of b.

pub fn to_low_3_bits(self) -> u8

Converts the wire type to the low 3-bits of a u8.

pub fn to_high_3_bits(self) -> u8

Converts the wire type to the high 3-bits of a u8.

Source

impl WireType

Decode

pub fn decode_fixed_2_byte<R>(r: &mut R, first: u8) -> Result<[u8; 2], Error>
where R: Read,

Decodes a Fixed2Byte value from the Read prefix given the first byte.

pub fn decode_fixed_4_byte<R>(r: &mut R, first: u8) -> Result<[u8; 4], Error>
where R: Read,

Decodes a Fixed4Byte value from the Read prefix given the first byte.

pub fn decode_fixed_8_byte<R>(r: &mut R, first: u8) -> Result<[u8; 8], Error>
where R: Read,

Decodes a Fixed8Byte value from the Read prefix given the first byte.

pub fn decode_fixed_16_byte<R>(r: &mut R, first: u8) -> Result<[u8; 16], Error>
where R: Read,

Decodes a Fixed16Byte value from the Read prefix given the first byte.

pub fn decode_length_prefixed_bytes<R>( r: &mut R, first: u8, ) -> Result<Vec<u8>, DecodingError>
where R: Read,

Decodes a LengthPrefixed []u8 value from the Read prefix given the first byte.

Source

impl WireType

Transfer

pub fn transfer<R, W>(self, r: &mut R, w: &mut W) -> Result<(), Error>
where R: Read, W: Write,

Transfers the encoded value for this wire type from r to w.

This reads the value bytes from r and writes them to w. The field header has already been consumed — this transfers only the value payload.